From 007b5994553cf3e9bdc7ce5e9eab4928743858b5 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?J=C3=B8r=E2=88=82=C2=A1?= <itsbrickpop@gmail.com>
Date: Thu, 5 Dec 2024 15:39:38 +0100
Subject: [PATCH] Last touches

---
 src/EmergencyMultisig.sol             | 10 +++++-----
 src/Multisig.sol                      | 10 +++++-----
 src/SignerList.sol                    |  6 +++---
 src/interfaces/IEmergencyMultisig.sol |  2 +-
 src/interfaces/IMultisig.sol          |  2 +-
 5 files changed, 15 insertions(+), 15 deletions(-)

diff --git a/src/interfaces/IEmergencyMultisig.sol b/src/interfaces/IEmergencyMultisig.sol
index b57f8c8..85d5907 100644
--- a/src/interfaces/IEmergencyMultisig.sol
+++ b/src/interfaces/IEmergencyMultisig.sol
@@ -14,7 +14,7 @@ interface IEmergencyMultisig {
 
     /// @notice Checks if an account can participate on a proposal vote. This can be because the vote
     /// - was executed, or
-    /// - the voter is not listed.
+    /// - the approver is not listed or appointed.
     /// @param _proposalId The proposal Id.
     /// @param _account The address of the user to check.
     /// @return Returns true if the account is allowed to vote.
diff --git a/src/interfaces/IMultisig.sol b/src/interfaces/IMultisig.sol
index 79e9e66..658b474 100644
--- a/src/interfaces/IMultisig.sol
+++ b/src/interfaces/IMultisig.sol
@@ -15,7 +15,7 @@ interface IMultisig {
 
     /// @notice Checks if an account can participate on a proposal vote. This can be because the vote
     /// - was executed, or
-    /// - the voter is not listed.
+    /// - the approver is not listed or appointed.
     /// @param _proposalId The proposal Id.
     /// @param _account The address of the user to check.
     /// @return Returns true if the account is allowed to vote.
diff --git a/src/EmergencyMultisig.sol b/src/EmergencyMultisig.sol
index 7a02f6e..5d25d41 100644
--- a/src/EmergencyMultisig.sol
+++ b/src/EmergencyMultisig.sol
@@ -357,17 +357,17 @@ contract EmergencyMultisig is IEmergencyMultisig, PluginUUPSUpgradeable, Proposa
 
         // This internally calls `isListedAtBlock`.
         // If not listed or resolved, it returns address(0)
-        (address _resolvedOwner, address _resolvedVoter) =
+        (address _owner, address _agent) =
             multisigSettings.signerList.resolveEncryptionAccountAtBlock(_approver, proposal_.parameters.snapshotBlock);
-        if (_resolvedOwner == address(0) || _resolvedVoter == address(0)) {
+        if (_owner == address(0) || _agent == address(0)) {
             // Not listedAtBlock() nor appointed by a listed owner
             return false;
-        } else if (_approver != _resolvedVoter) {
-            // Only the voter account can vote (owners who appointed, can't)
+        } else if (_approver != _agent) {
+            // Only the agent can vote (owners who appointed, can't)
             return false;
         }
 
-        if (proposal_.approvers[_resolvedOwner]) {
+        if (proposal_.approvers[_owner]) {
             // The account already approved
             return false;
         }
diff --git a/src/Multisig.sol b/src/Multisig.sol
index 976039b..a326237 100644
--- a/src/Multisig.sol
+++ b/src/Multisig.sol
@@ -342,17 +342,17 @@ contract Multisig is IMultisig, PluginUUPSUpgradeable, ProposalUpgradeable {
 
         // This internally calls `isListedAtBlock`.
         // If not listed or resolved, it returns address(0)
-        (address _resolvedOwner, address _resolvedVoter) =
+        (address _owner, address _agent) =
             multisigSettings.signerList.resolveEncryptionAccountAtBlock(_approver, proposal_.parameters.snapshotBlock);
-        if (_resolvedOwner == address(0) || _resolvedVoter == address(0)) {
+        if (_owner == address(0) || _agent == address(0)) {
             // Not listedAtBlock() nor appointed by a listed owner
             return false;
-        } else if (_approver != _resolvedVoter) {
-            // Only the voter account can vote (owners who appointed, can't)
+        } else if (_approver != _agent) {
+            // Only the agent can vote (owners who appointed, can't)
             return false;
         }
 
-        if (proposal_.approvers[_resolvedOwner]) {
+        if (proposal_.approvers[_owner]) {
             // The account already approved
             return false;
         }
diff --git a/src/SignerList.sol b/src/SignerList.sol
index 19bc211..09b95f3 100644
--- a/src/SignerList.sol
+++ b/src/SignerList.sol
@@ -134,16 +134,16 @@ contract SignerList is ISignerList, Addresslist, ERC165Upgradeable, DaoAuthoriza
     function resolveEncryptionAccountAtBlock(address _address, uint256 _blockNumber)
         public
         view
-        returns (address _owner, address _voter)
+        returns (address _owner, address _agent)
     {
         if (isListedAtBlock(_address, _blockNumber)) {
             // The owner + the voter
             return (_address, settings.encryptionRegistry.getAppointedAgent(_address));
         }
 
         address _appointer = settings.encryptionRegistry.appointerOf(_address);
         if (this.isListedAtBlock(_appointer, _blockNumber)) {
             // The appointed wallet votes
             return (_appointer, _address);
         }
 
@@ -134,16 +134,16 @@ contract SignerList is ISignerList, Addresslist, ERC165Upgradeable, DaoAuthoriza
     {
         if (isListedAtBlock(_address, _blockNumber)) {
-            // The owner + the voter
+            // The owner + the agent
             return (_address, settings.encryptionRegistry.getAppointedAgent(_address));
         }
@@ -134,16 +134,16 @@ contract SignerList is ISignerList, Addresslist, ERC165Upgradeable, DaoAuthoriza
         address _appointer = settings.encryptionRegistry.appointerOf(_address);
         if (this.isListedAtBlock(_appointer, _blockNumber)) {
-            // The appointed wallet votes
+            // The appointed agent votes
             return (_appointer, _address);
         }